@@ -8,7 +8,8 @@ import pathlib
 from typing import Type, Iterable
 from collections.abc import Mapping
 from collections import UserDict
-from test import support
+
+from compat import support, os_helper
 
 from backports import configparser
 
@@ -85,6 +86,7 @@ class BasicTestCase(CfgParserTestCaseClass):
             'Spacey Bar',
             'Spacey Bar From The Beginning',
             'Types',
+            'This One Has A ] In It',
         ]
 
         if self.allow_no_value:
@@ -136,6 +138,7 @@ class BasicTestCase(CfgParserTestCaseClass):
         eq(cf.get('Types', 'float'), "0.44")
         eq(cf.getboolean('Types', 'boolean'), False)
         eq(cf.get('Types', '123'), 'strange but acceptable')
+        eq(cf.get('This One Has A ] In It', 'forks'), 'spoons')
         if self.allow_no_value:
             eq(cf.get('NoValue', 'option-without-value'), None)
 
@@ -327,6 +330,8 @@ int {0[1]} 42
 float {0[0]} 0.44
 boolean {0[0]} NO
 123 {0[1]} strange but acceptable
+[This One Has A ] In It]
+  forks {0[0]} spoons
 """.format(
             self.delimiters, self.comment_prefixes
         )
@@ -409,6 +414,7 @@ boolean {0[0]} NO
                 "boolean": False,
                 123: "strange but acceptable",
             },
+            "This One Has A ] In It": {"forks": "spoons"},
         }
         if self.allow_no_value:
             config.update({"NoValue": {"option-without-value": None}})
@@ -762,31 +768,31 @@ boolean {0[0]} NO
         file1 = support.findfile("cfgparser.1")
         # check when we pass a mix of readable and non-readable files:
         cf = self.newconfig()
-        parsed_files = cf.read([file1, "nonexistent-file"])
+        parsed_files = cf.read([file1, "nonexistent-file"], encoding="utf-8")
         self.assertEqual(parsed_files, [file1])
         self.assertEqual(cf.get("Foo Bar", "foo"), "newbar")
         # check when we pass only a filename:
         cf = self.newconfig()
-        parsed_files = cf.read(file1)
+        parsed_files = cf.read(file1, encoding="utf-8")
         self.assertEqual(parsed_files, [file1])
         self.assertEqual(cf.get("Foo Bar", "foo"), "newbar")
         # check when we pass only a Path object:
         cf = self.newconfig()
-        parsed_files = cf.read(pathlib.Path(file1))
+        parsed_files = cf.read(pathlib.Path(file1), encoding="utf-8")
         self.assertEqual(parsed_files, [file1])
         self.assertEqual(cf.get("Foo Bar", "foo"), "newbar")
         # check when we passed both a filename and a Path object:
         cf = self.newconfig()
-        parsed_files = cf.read([pathlib.Path(file1), file1])
+        parsed_files = cf.read([pathlib.Path(file1), file1], encoding="utf-8")
         self.assertEqual(parsed_files, [file1, file1])
         self.assertEqual(cf.get("Foo Bar", "foo"), "newbar")
         # check when we pass only missing files:
         cf = self.newconfig()
-        parsed_files = cf.read(["nonexistent-file"])
+        parsed_files = cf.read(["nonexistent-file"], encoding="utf-8")
         self.assertEqual(parsed_files, [])
         # check when we pass no files:
         cf = self.newconfig()
-        parsed_files = cf.read([])
+        parsed_files = cf.read([], encoding="utf-8")
         self.assertEqual(parsed_files, [])
 
     def test_read_returns_file_list_with_bytestring_path(self):
@@ -795,15 +801,17 @@ boolean {0[0]} NO
         file1_bytestring = support.findfile("cfgparser.1").encode()
         # check when passing an existing bytestring path
         cf = self.newconfig()
-        parsed_files = cf.read(file1_bytestring)
+        parsed_files = cf.read(file1_bytestring, encoding="utf-8")
         self.assertEqual(parsed_files, [file1_bytestring])
         # check when passing an non-existing bytestring path
         cf = self.newconfig()
-        parsed_files = cf.read(b'nonexistent-file')
+        parsed_files = cf.read(b'nonexistent-file', encoding="utf-8")
         self.assertEqual(parsed_files, [])
         # check when passing both an existing and non-existing bytestring path
         cf = self.newconfig()
-        parsed_files = cf.read([file1_bytestring, b'nonexistent-file'])
+        parsed_files = cf.read(
+            [file1_bytestring, b'nonexistent-file'], encoding="utf-8"
+        )
         self.assertEqual(parsed_files, [file1_bytestring])
 
     # shared by subclasses
@@ -1164,18 +1172,18 @@ class MultilineValuesTestCase(BasicTestCase, unittest.TestCase):
             s = 'section{0}'.format(i)
             cf.add_section(s)
             for j in range(10):
-                cf.set(s, 'lovely_spam{0}'.format(j), self.wonderful_spam)
-        with open(support.TESTFN, 'w') as f:
+                cf.set(s, 'lovely_spam{}'.format(j), self.wonderful_spam)
+        with open(os_helper.TESTFN, 'w', encoding="utf-8") as f:
             cf.write(f)
 
     def tearDown(self):
-        os.unlink(support.TESTFN)
+        os.unlink(os_helper.TESTFN)
 
     def test_dominating_multiline_values(self):
         # We're reading from file because this is where the code changed
         # during performance updates in Python 3.2
         cf_from_file = self.newconfig()
-        with open(support.TESTFN) as f:
+        with open(os_helper.TESTFN, encoding="utf-8") as f:
             cf_from_file.read_file(f)
         self.assertEqual(
             cf_from_file.get('section8', 'lovely_spam4'),
@@ -1602,7 +1610,7 @@ class CopyTestCase(BasicTestCase, unittest.TestCase):
 class FakeFile(object):
     def __init__(self):
         file_path = support.findfile("cfgparser.1")
-        with open(file_path) as f:
+        with open(file_path, encoding="utf-8") as f:
             self.lines = f.readlines()
             self.lines.reverse()
 
@@ -1629,7 +1637,7 @@ class ReadFileTestCase(unittest.TestCase):
             pass  # unfortunately we can't test bytes on this path
         for file_path in file_paths:
             parser = configparser.ConfigParser()
-            with open(file_path) as f:
+            with open(file_path, encoding="utf-8") as f:
                 parser.read_file(f)
             self.assertIn("Foo Bar", parser)
             self.assertIn("foo", parser["Foo Bar"])
@@ -2339,80 +2347,8 @@ class BlatantOverrideConvertersTestCase(unittest.TestCase):
 
 
 class MiscTestCase(unittest.TestCase):
-    @unittest.skipIf(not hasattr(support, 'check__all__'), "check__all__ not available")
     def test__all__(self):
-        blacklist = {"Error", "PY2"}
-        support.check__all__(self, configparser, blacklist=blacklist)
-
-
-class UnicodeBackportTestCase(unittest.TestCase):
-    """Test for the backport to check if the Unicode coercion works."""
-
-    def test_unicode_none_old_style(self):
-        cp = configparser.ConfigParser(allow_no_value=True)
-        cp.add_section("section")
-        self.assertIsInstance(cp.sections()[0], str)
-        self.assertIsInstance([sect for sect in cp][0], str)
-        cp.set("section", "nothing", None)
-        self.assertIsAlright(cp, None)
-
-    def test_unicode_none_new_style(self):
-        cp = configparser.ConfigParser(allow_no_value=True)
-        cp["section"] = {}
-        self.assertIsInstance(cp.sections()[0], str)
-        self.assertIsInstance([sect for sect in cp][0], str)
-        cp["section"]["nothing"] = None
-        self.assertIsAlright(cp, None)
-
-    def test_unicode_none_new_style_one_step(self):
-        cp = configparser.ConfigParser(allow_no_value=True)
-        cp["section"] = {'nothing': None}
-        self.assertIsAlright(cp, None)
-
-    def test_unicode_unicode_old_style(self):
-        cp = configparser.ConfigParser()
-        cp.add_section("section")
-        self.assertIsInstance(cp.sections()[0], str)
-        self.assertIsInstance([sect for sect in cp][0], str)
-        cp.set("section", "nothing", "nada")
-        self.assertIsAlright(cp, "nada")
-
-    def test_unicode_unicode_new_style(self):
-        cp = configparser.ConfigParser()
-        cp["section"] = {}
-        self.assertIsInstance(cp.sections()[0], str)
-        self.assertIsInstance([sect for sect in cp][0], str)
-        cp["section"]["nothing"] = "nada"
-        self.assertIsAlright(cp, "nada")
-
-    def test_unicode_unicode_new_style_one_step(self):
-        cp = configparser.ConfigParser()
-        cp['section'] = {'nothing': 'nada'}
-        self.assertIsAlright(cp, 'nada')
-
-    def test_unicode_extended_characters(self):
-        cp = configparser.ConfigParser()
-        cp.add_section('section')
-        cp.add_section('łąka1')
-        cp['łąka2'] = {}
-        cp.set('section', 'łąka1', 'value')
-        cp['section']['łąka2'] = 'value'
-        self.assertEqual(set(cp['section']), set(['łąka1', 'łąka2']))
-        cp['new'] = {'łąka': 'value'}
-        cp.set('section', 'key', 'łąka')
-        cp['section']['key'] = 'łąka'
-        self.assertEqual(cp['section']['key'], 'łąka')
-        cp['new'] = {'key': 'łąka'}
-
-    def assertIsAlright(self, cp, optvalue):
-        self.assertIn('section', cp)
-        self.assertIn('nothing', cp['section'])
-        self.assertIsInstance(cp.sections()[0], str)
-        self.assertIsInstance(cp.options('section')[0], str)
-        self.assertEqual(cp.get('section', 'nothing'), optvalue)
-        self.assertIsInstance([sect for sect in cp][0], str)
-        self.assertIsInstance([opt for opt in cp['section']][0], str)
-        self.assertEqual(cp['section']['nothing'], optvalue)
+        support.check__all__(self, configparser, not_exported={"Error"})
 
 
 if __name__ == '__main__':
